@@ -16,11 +16,10 @@ OpsAstrometryIndexFiles::OpsAstrometryIndexFiles(Align *parent) : QDialog(KStars
 {
     setupUi(this);
 
-    downloadSpeed=100;
-    actualdownloadSpeed=downloadSpeed;
-
-    alignModule = parent;
-    manager     = new QNetworkAccessManager();
+    downloadSpeed       = 100;
+    actualdownloadSpeed = downloadSpeed;
+    alignModule         = parent;
+    manager             = new QNetworkAccessManager();
 
     //Get a pointer to the KConfigDialog
     // m_ConfigDialog = KConfigDialog::exists( "alignsettings" );
@@ -60,13 +59,19 @@ OpsAstrometryIndexFiles::OpsAstrometryIndexFiles(Align *parent) : QDialog(KStars
 
     for (auto &bar : progressBars)
     {
-        bar->setVisible(false);
-        bar->setTextVisible(false);
+        if(bar->objectName().contains("progress"))
+        {
+            bar->setVisible(false);
+            bar->setTextVisible(false);
+        }
     }
 
     for (auto &button : qButtons)
     {
-        button->setVisible(false);
+        if(button->objectName().contains("cancel"))
+        {
+            button->setVisible(false);
+        }
     }
 
     for (QLabel * label: qLabels)
@@ -80,10 +85,6 @@ OpsAstrometryIndexFiles::OpsAstrometryIndexFiles(Align *parent) : QDialog(KStars
 
 }
 
-OpsAstrometryIndexFiles::~OpsAstrometryIndexFiles()
-{
-}
-
 void OpsAstrometryIndexFiles::showEvent(QShowEvent *)
 {
     slotUpdate();
@@ -125,7 +126,7 @@ void OpsAstrometryIndexFiles::slotUpdate()
 
     for (auto &checkBox : checkboxes)
     {
-        checkBox->setIcon(QIcon::fromTheme("security-low.svg"));
+        checkBox->setIcon(QIcon(":/icons/astrometry-optional.svg"));
         checkBox->setToolTip(i18n("Optional"));
     }
 
@@ -142,12 +143,12 @@ void OpsAstrometryIndexFiles::slotUpdate()
             QCheckBox *indexCheckBox2 = findChild<QCheckBox *>(indexName2);
             if (indexCheckBox1)
             {
-                indexCheckBox1->setIcon(QIcon::fromTheme("security-high.svg"));
+                indexCheckBox1->setIcon(QIcon(":/icons/astrometry-required.svg"));
                 indexCheckBox1->setToolTip(i18n("Required"));
             }
             if (indexCheckBox2)
             {
-                indexCheckBox2->setIcon(QIcon::fromTheme("security-high.svg"));
+                indexCheckBox2->setIcon(QIcon(":/icons/astrometry-required.svg"));
                 indexCheckBox2->setToolTip(i18n("Required"));
             }
         }
@@ -159,12 +160,12 @@ void OpsAstrometryIndexFiles::slotUpdate()
             QCheckBox *indexCheckBox2 = findChild<QCheckBox *>(indexName2);
             if (indexCheckBox1)
             {
-                indexCheckBox1->setIcon(QIcon::fromTheme("security-medium.svg"));
+                indexCheckBox1->setIcon(QIcon(":/icons/astrometry-recommended.svg"));
                 indexCheckBox1->setToolTip(i18n("Recommended"));
             }
             if (indexCheckBox2)
             {
-                indexCheckBox2->setIcon(QIcon::fromTheme("security-medium.svg"));
+                indexCheckBox2->setIcon(QIcon(":/icons/astrometry-recommended.svg"));
                 indexCheckBox2->setToolTip(i18n("Recommended"));
             }
         }
@@ -277,7 +278,7 @@ void OpsAstrometryIndexFiles::downloadIndexFile(const QString &URL, const QStrin
     if(indexDownloadInfo){
         if (indexDownloadProgress && maxIndex > 0)
             indexDownloadProgress->setValue(currentIndex*100 / maxIndex);
-        indexDownloadInfo->setText("(" + QString::number(currentIndex) + "/" + QString::number(maxIndex + 1) + ") ");
+        indexDownloadInfo->setText("(" + QString::number(currentIndex) + '/' + QString::number(maxIndex + 1) + ") ");
     }
 
     QString indexURL = URL;
@@ -306,7 +307,7 @@ void OpsAstrometryIndexFiles::downloadIndexFile(const QString &URL, const QStrin
                 indexDownloadProgress->setValue(bytesReceived);
                 indexDownloadProgress->setMaximum(bytesTotal);
             }
-            indexDownloadPerc->setText(QString::number(bytesReceived*100/bytesTotal)+"%");
+            indexDownloadPerc->setText(QString::number(bytesReceived * 100 / bytesTotal) + '%');
         });
 
     }
