@@ -9,21 +9,21 @@
 
 #include "filtermanager.h"
 
-#include <QSqlTableModel>
-#include <QSqlDatabase>
-#include <QSqlRecord>
-#include <algorithm>
-
-#include <basedevice.h>
-
+#include "indi_debug.h"
 #include "kstarsdata.h"
 #include "kstars.h"
+#include "Options.h"
 #include "auxiliary/kspaths.h"
 #include "ekos/auxiliary/filterdelegate.h"
 
-#include "indi_debug.h"
 
-#include "Options.h"
+#include <QSqlTableModel>
+#include <QSqlDatabase>
+#include <QSqlRecord>
+
+#include <basedevice.h>
+
+#include <algorithm>
 
 namespace Ekos
 {
@@ -81,7 +81,7 @@ FilterManager::FilterManager() : QDialog(KStars::Instance())
 
 void FilterManager::refreshFilterModel()
 {
-    if (m_currentFilterDevice == nullptr)
+    if (m_currentFilterDevice == nullptr || m_currentFilterLabels.empty())
         return;
 
     QString vendor(m_currentFilterDevice->getDeviceName());
@@ -111,7 +111,7 @@ void FilterManager::refreshFilterModel()
     // If it is first time, let's populate data
     if (filterModel->rowCount() == 0)
     {
-        for (QString filter : m_currentFilterLabels)
+        for (QString &filter : m_currentFilterLabels)
             KStarsData::Instance()->userdb()->AddFilter(vendor, "", "", filter, 0, 1.0, false, "--", 0);
 
         filterModel->select();
@@ -189,7 +189,7 @@ void FilterManager::reloadFilters()
     }
 }
 
-void FilterManager::setCurrentFilter(ISD::GDInterface *filter)
+void FilterManager::setCurrentFilterWheel(ISD::GDInterface *filter)
 {
     if (m_currentFilterDevice == filter)
         return;
@@ -214,12 +214,13 @@ void FilterManager::setCurrentFilter(ISD::GDInterface *filter)
     if (m_currentFilterLabels.isEmpty() == false)
         refreshFilterModel();
 
-    lastFilterOffset = m_ActiveFilters[m_currentFilterPosition-1]->offset();
+    if (m_ActiveFilters.count() >= m_currentFilterPosition)
+        lastFilterOffset = m_ActiveFilters[m_currentFilterPosition-1]->offset();
 }
 
 QStringList FilterManager::getFilterLabels(bool forceRefresh)
 {
-    if (forceRefresh == false)
+    if (forceRefresh == false || m_FilterNameProperty == nullptr)
         return m_currentFilterLabels;
 
     QStringList filterList;
@@ -234,8 +235,6 @@ QStringList FilterManager::getFilterLabels(bool forceRefresh)
             item = m_FilterNameProperty->tp[i].text;
         else if (i < filterAlias.count() && filterAlias[i].isEmpty() == false)
             item = filterAlias.at(i);
-        else
-            item = QString("Filter_%1").arg(i + 1);
 
         filterList.append(item);
     }
@@ -290,7 +289,7 @@ void FilterManager::processNumber(INumberVectorProperty *nvp)
     if (state == FILTER_CHANGE)
         executeOperationQueue();
     // If filter is changed externally, record its current offset as the starting offset.
-    else if (state == FILTER_IDLE)
+    else if (state == FILTER_IDLE && m_ActiveFilters.count() >= m_currentFilterPosition)
         lastFilterOffset = m_ActiveFilters[m_currentFilterPosition-1]->offset();
 
     // Check if we have to apply Focus Offset
@@ -413,11 +412,11 @@ void FilterManager::buildOperationQueue(FilterState operation)
         if (m_useTargetFilter)
         {            
             operationQueue.enqueue(FILTER_CHANGE);
-            if (m_Policy & OFFSET_POLICY)
+            if (m_FocusReady && (m_Policy & OFFSET_POLICY))
                 operationQueue.enqueue(FILTER_OFFSET);
         }
 
-        if ( (m_Policy & AUTOFOCUS_POLICY) && targetFilter->useAutoFocus())
+        if (m_FocusReady && (m_Policy & AUTOFOCUS_POLICY) && targetFilter->useAutoFocus())
             operationQueue.enqueue(FILTER_AUTOFOCUS);
     }
         break;
@@ -512,6 +511,9 @@ void FilterManager::setFocusOffsetComplete()
 
 double FilterManager::getFilterExposure(const QString &name) const
 {
+    if (m_currentFilterLabels.empty())
+        return 1;
+
     QString color = name;
     if (color.isEmpty())
         color = m_currentFilterLabels[m_currentFilterPosition-1];
@@ -528,6 +530,9 @@ double FilterManager::getFilterExposure(const QString &name) const
 
 bool FilterManager::setFilterExposure(int index, double exposure)
 {
+    if (m_currentFilterLabels.empty())
+        return false;
+
      QString color = m_currentFilterLabels[index];
      for (int i=0; i < m_ActiveFilters.count(); i++)
      {
