@@ -120,8 +120,9 @@ class Capture : public QWidget, public Ui::Capture
     /** DBUS interface function.
          * select the filter device from the available filter drivers. The filter device can be the same as the CCD driver if the filter functionality was embedded within the driver.
          * @param device The filter device name
+         * @param filter the filter name
          */
-    Q_SCRIPTABLE bool setFilter(QString device, int filterSlot);
+    Q_SCRIPTABLE bool setFilter(const QString &device, const QString &filter);
 
     /** DBUS interface function.
          * Aborts any current jobs and remove all sequence queue jobs.
@@ -290,6 +291,18 @@ class Capture : public QWidget, public Ui::Capture
     /* Capture */
     void updateSequencePrefix(const QString &newPrefix, const QString &dir);
 
+    /**
+     * @brief getSequence Return the JSON representation of the current sequeue queue
+     * @return Reference to JSON array containing sequence queue jobs.
+     */
+    const QJsonArray &getSequence() const { return m_SequenceArray;}
+
+    /**
+     * @brief setSettings Set capture settings
+     * @param settings list of settings
+     */
+    void setSettings(const QJsonObject &settings);
+
   public slots:
 
     /** \addtogroup CaptureDBusInterface
@@ -314,6 +327,13 @@ class Capture : public QWidget, public Ui::Capture
          */
     Q_SCRIPTABLE Q_NOREPLY void abort() { stop(true); }
 
+
+    /** DBUS interface function.
+         * Toggle video streaming if supported by the device.
+         * @param enabled Set to true to start video streaming, false to stop it if active.
+         */
+    Q_SCRIPTABLE Q_NOREPLY void toggleVideo(bool enabled);
+
     /** @}*/
 
     /**
@@ -321,6 +341,43 @@ class Capture : public QWidget, public Ui::Capture
          */
     void captureOne();
 
+    /**
+     * @brief setExposure Set desired exposure value in seconds
+     * @param value exposure values in seconds
+     */
+    void setExposure(double value) { exposureIN->setValue(value);}
+
+    /**
+     * @brief seqCount Set required number of images to capture in one sequence job
+     * @param count number of images to capture
+     */
+    void setCount(uint16_t count) { countIN->setValue(count); }
+
+    /**
+     * @brief setDelay Set delay between capturing images within a sequence in seconds
+     * @param delay numbers of seconds to wait before starting the next image.
+     */
+    void setDelay(uint16_t delay) { delayIN->setValue(delay);}
+
+    /**
+     * @brief setPrefix Set target or prefix name used in constructing the generated file name
+     * @param prefix Leading text of the generated image name.
+     */
+    void setPrefix(const QString &prefix) { prefixIN->setText(prefix);}
+
+    /**
+     * @brief setBinning Set binning
+     * @param horBin Horizontal binning
+     * @param verBin Vertical binning
+     */
+    void setBinning(int horBin, int verBin) { binXIN->setValue(horBin); binYIN->setValue(verBin); }
+
+    /**
+     * @brief setISO Set index of ISO list.
+     * @param index index of ISO list.
+     */
+    void setISO(int index) { ISOCombo->setCurrentIndex(index);}
+
     /**
          * @brief captureImage Initiates image capture in the active job.
          */
@@ -364,9 +421,11 @@ class Capture : public QWidget, public Ui::Capture
     bool addJob(bool preview = false);
 
     /**
-         * @brief removeJob Remove a job from the currently selected row. If no row is selected, it remove the last job in the queue.
-         */
-    void removeJob();
+     * @brief removeJob Remove a job sequence from the queue
+     * @param index Row index for job to remove, if left as -1 (default), the currently selected row will be removed.
+     *        if no row is selected, the last job shall be removed.
+     */
+    void removeJob(int index=-1);
 
     /**
          * @brief moveJobUp Move the job in the sequence queue one place up.
@@ -397,15 +456,19 @@ class Capture : public QWidget, public Ui::Capture
     void updateCCDTemperature(double value);
 
     /**
-         * @brief setTemperature Set CCD temperature from the user GUI settings.
+         * @brief setTemperature Set the target CCD temperature in the GUI settings.
          */
-    void setTemperature();
+    void setTargetTemperature(double temperature);
+
+    void setForceTemperature(bool enabled) {temperatureCheck->setChecked(enabled);}
 
     /**
          * @brief preparePreCaptureActions Check if we need to update filter position or CCD temperature before starting capture process
          */
     void preparePreCaptureActions();
 
+    void setFrameType(const QString& type) {frameTypeCombo->setCurrentText(type);}
+
     // Pause Sequence Queue
     void pause();
 
@@ -414,7 +477,7 @@ class Capture : public QWidget, public Ui::Capture
 
     // Auto Focus
     void setFocusStatus(Ekos::FocusState state);
-    void setHFR(double newHFR) { focusHFR = newHFR; }
+    void setHFR(double newHFR, int) { focusHFR = newHFR; }
 
     // Guide
     void setGuideStatus(Ekos::GuideState state);
@@ -462,8 +525,8 @@ class Capture : public QWidget, public Ui::Capture
 
     // Auto Focus
     // Timed refocus
-    void startRefocusEveryNTimer();
-    void restartRefocusEveryNTimer();
+    void startRefocusEveryNTimer() { startRefocusTimer(false); }
+    void restartRefocusEveryNTimer() { startRefocusTimer(true); }
     int getRefocusEveryNTimerElapsedSec();
 
     // Flat field
@@ -481,12 +544,6 @@ class Capture : public QWidget, public Ui::Capture
     // post capture script
     void postScriptFinished(int exitCode);
 
-    // Filter focus offset
-    //void showFilterOffsetDialog();
-    //void loadFilterOffsets();
-
-    // Live Video Preview
-    void toggleVideoStream(bool enable);
     void setVideoStreamEnabled(bool enabled);
 
     // Observer
@@ -508,6 +565,8 @@ class Capture : public QWidget, public Ui::Capture
     void newStatus(Ekos::CaptureState status);
     void newImage(QImage *image, Ekos::SequenceJob *job);
     void newExposureProgress(Ekos::SequenceJob *job);
+    void sequenceChanged(const QJsonArray &sequence);
+    void settingsUpdated(const QJsonObject &settings);
 
   private:
     void setBusy(bool enable);
@@ -542,9 +601,22 @@ class Capture : public QWidget, public Ui::Capture
 
     void resetFrameToZero();
 
+    /* Refocus */
+    void startRefocusTimer(bool forced = false);
+
     /* Capture */
+
+    /**
+     * @brief Determine the overall number of target frames with the same signature.
+     *        Assume capturing RGBLRGB, where in each sequence job there is only one frame.
+     *        For "L" the result will be 1, for "R" it will be 2 etc.
+     * @param frame signature (typically the filter name)
+     * @return
+     */
+    int getTotalFramesCount(QString signature);
+
     double seqExpose { 0 };
-    int seqTotalCount { 0 };
+    int seqTotalCount;
     int seqCurrentCount { 0 };
     int seqDelay { 0 };
     int retries { 0 };
@@ -556,6 +628,7 @@ class Capture : public QWidget, public Ui::Capture
 
     bool useGuideHead { false };
     bool autoGuideReady { false};
+    bool autoGuideAbortedCapture { false };
 
     QString targetName;
     QString observerName;
@@ -637,6 +710,7 @@ class Capture : public QWidget, public Ui::Capture
     // Misc
     bool ignoreJobProgress { true };
     bool suspendGuideOnDownload { false };
+    QJsonArray m_SequenceArray;
 
     // State
     CaptureState state { CAPTURE_IDLE };
