@@ -47,7 +47,7 @@ class SequenceJob : public QObject
     } PrepareActions;
 
     SequenceJob();
-    ~SequenceJob() {}
+    ~SequenceJob() = default;
 
     CAPTUREResult capture(bool noCaptureFilter);
     void reset();
@@ -78,6 +78,7 @@ class SequenceJob : public QObject
 
     void setLocalDir(const QString &dir) { localDirectory = dir; }
     const QString &getLocalDir() { return localDirectory; }
+    QString getSignature() { return getLocalDir() + getDirectoryPostfix(); }
 
     void setTargetFilter(int pos, const QString &name);
     int getTargetFilter() { return targetFilter; }
