@@ -11,17 +11,18 @@
 
 #include "internalguider.h"
 
+#include "ekos_guide_debug.h"
 #include "gmath.h"
 #include "Options.h"
 #include "auxiliary/kspaths.h"
 #include "fitsviewer/fitsdata.h"
 #include "fitsviewer/fitsview.h"
-
-#include "ekos_guide_debug.h"
+#include "ksnotification.h"
 
 #include <KMessageBox>
-#include <KNotification>
 
+#include <random>
+#include <chrono>
 #include <QTimer>
 
 #define MAX_GUIDE_STARS           10
@@ -109,6 +110,7 @@ bool InternalGuider::abort()
 
     m_starLostCounter=0;
     m_highPulseCounter=0;
+    accumulator.first = accumulator.second = 0;
 
     pmath->suspend(false);
     state = GUIDE_IDLE;
@@ -138,44 +140,56 @@ bool InternalGuider::resume()
     return true;
 }
 
-bool InternalGuider::dither(double pixels)
+bool InternalGuider::ditherXY(int x, int y)
 {
-    static Vector target_pos;
-    static unsigned int retries = 0;
+    ditherRetries=0;
+    double cur_x, cur_y, ret_angle;
+    pmath->getReticleParameters(&cur_x, &cur_y, &ret_angle);
+    ditherTargetPosition = Vector(x, y, 0);
+    pmath->setReticleParameters(ditherTargetPosition.x, ditherTargetPosition.y, ret_angle);
 
-    //if (ui.ditherCheck->isChecked() == false)
-    //return false;
+    state = GUIDE_DITHERING;
+    emit newStatus(state);
 
+    processGuiding();
+
+    return true;
+}
+
+bool InternalGuider::dither(double pixels)
+{        
     double cur_x, cur_y, ret_angle;
     pmath->getReticleParameters(&cur_x, &cur_y, &ret_angle);
     pmath->getStarScreenPosition(&cur_x, &cur_y);
-    Ekos::Matrix ROT_Z = pmath->getROTZ();
-
-    //qDebug() << "Star Pos X " << cur_x << " Y " << cur_y;
+    Ekos::Matrix ROT_Z = pmath->getROTZ();   
 
     if (state != GUIDE_DITHERING)
     {
-        retries = 0;
+        ditherRetries = 0;
 
-        // JM 2016-05-8: CCD would abort if required.
-        //targetChip->abortExposure();
+        auto seed = std::chrono::system_clock::now().time_since_epoch().count();
+        std::default_random_engine generator(seed);
+        std::uniform_real_distribution<double> angleMagnitude(0, 360);
 
-        int polarity  = (rand() % 2 == 0) ? 1 : -1;
-        double angle  = ((double)rand() / RAND_MAX) * M_PI / 2.0;
+        double angle  = angleMagnitude(generator) * dms::DegToRad;
         double diff_x = pixels * cos(angle);
         double diff_y = pixels * sin(angle);
 
         if (pmath->declinationSwapEnabled())
             diff_y *= -1;
 
-        if (polarity > 0)
-            target_pos = Vector(cur_x, cur_y, 0) + Vector(diff_x, diff_y, 0);
-        else
-            target_pos = Vector(cur_x, cur_y, 0) - Vector(diff_x, diff_y, 0);
+        if (fabs(diff_x + accumulator.first) > MAX_DITHER_TRAVEL)
+            diff_x *= -1;
+        accumulator.first += diff_x;
+        if (fabs(diff_y + accumulator.second) > MAX_DITHER_TRAVEL)
+            diff_y *= -1;
+        accumulator.second += diff_y;
 
-        qCDebug(KSTARS_EKOS_GUIDE) << "Dithering process started.. Reticle Target Pos X " << target_pos.x << " Y " << target_pos.y;
+        ditherTargetPosition = Vector(cur_x, cur_y, 0) + Vector(diff_x, diff_y, 0);
 
-        pmath->setReticleParameters(target_pos.x, target_pos.y, ret_angle);
+        qCDebug(KSTARS_EKOS_GUIDE) << "Dithering process started.. Reticle Target Pos X " << ditherTargetPosition.x << " Y " << ditherTargetPosition.y;
+
+        pmath->setReticleParameters(ditherTargetPosition.x, ditherTargetPosition.y, ret_angle);
 
         state = GUIDE_DITHERING;
         emit newStatus(state);
@@ -185,7 +199,7 @@ bool InternalGuider::dither(double pixels)
         return true;
     }
 
-    Vector star_pos = Vector(cur_x, cur_y, 0) - Vector(target_pos.x, target_pos.y, 0);
+    Vector star_pos = Vector(cur_x, cur_y, 0) - Vector(ditherTargetPosition.x, ditherTargetPosition.y, 0);
     star_pos.y      = -star_pos.y;
     star_pos        = star_pos * ROT_Z;
 
@@ -206,7 +220,7 @@ bool InternalGuider::dither(double pixels)
     }
     else
     {
-        if (++retries > Options::ditherMaxIterations())
+        if (++ditherRetries > Options::ditherMaxIterations())
         {
             if (Options::ditherFailAbortsAutoGuide())
             {
@@ -436,7 +450,7 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
 
             emit newStatus(Ekos::GUIDE_CALIBRATION_ERROR);
 
-            KNotification::event(QLatin1String("CalibrationFailed"), i18n("Guiding calibration failed with errors"));
+            KSNotification::event(QLatin1String("CalibrationFailed"), i18n("Guiding calibration failed with errors"), KSNotification::EVENT_ALERT);
 
             reset();
         }
@@ -522,7 +536,7 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
                               "backlash problems...",
                               ra_iterations));
 
-            KNotification::event(QLatin1String("CalibrationFailed"), i18n("Guiding calibration failed with errors"));
+            KSNotification::event(QLatin1String("CalibrationFailed"), i18n("Guiding calibration failed with errors"), KSNotification::EVENT_ALERT);
             reset();
             break;
         }
@@ -552,7 +566,7 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
 
             emit newStatus(Ekos::GUIDE_CALIBRATION_SUCESS);
 
-            KNotification::event(QLatin1String("CalibrationSuccessful"),
+            KSNotification::event(QLatin1String("CalibrationSuccessful"),
                                  i18n("Guiding calibration completed successfully"));
         }
         else
@@ -563,8 +577,8 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
 
             emit newStatus(Ekos::GUIDE_CALIBRATION_ERROR);
 
-            KNotification::event(QLatin1String("CalibrationFailed"),
-                                 i18n("Guiding calibration failed with errors"));
+            KSNotification::event(QLatin1String("CalibrationFailed"),
+                                 i18n("Guiding calibration failed with errors"), KSNotification::EVENT_ALERT);
         }
 
         reset();
@@ -615,8 +629,8 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
                               "or backlash problems...",
                               dec_iterations));
 
-            KNotification::event(QLatin1String("CalibrationFailed"),
-                                 i18n("Guiding calibration failed with errors"));
+            KSNotification::event(QLatin1String("CalibrationFailed"),
+                                 i18n("Guiding calibration failed with errors"), KSNotification::EVENT_ALERT);
             reset();
         }
         else
@@ -696,8 +710,8 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
                               "or backlash problems...",
                               dec_iterations));
 
-            KNotification::event(QLatin1String("CalibrationFailed"),
-                                 i18n("Guiding calibration failed with errors"));
+            KSNotification::event(QLatin1String("CalibrationFailed"),
+                                 i18n("Guiding calibration failed with errors"),KSNotification::EVENT_ALERT);
             reset();
             break;
         }
@@ -718,7 +732,7 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
 
             emit DESwapChanged(swap_dec);
 
-            KNotification::event(QLatin1String("CalibrationSuccessful"),
+            KSNotification::event(QLatin1String("CalibrationSuccessful"),
                                  i18n("Guiding calibration completed successfully"));
 
             //if (ui.autoStarCheck->isChecked())
@@ -732,8 +746,8 @@ void InternalGuider::calibrateRADECRecticle(bool ra_only)
 
             //ui.startCalibrationLED->setColor(alertColor);
             calibrationStage = CAL_ERROR;
-            KNotification::event(QLatin1String("CalibrationFailed"),
-                                 i18n("Guiding calibration failed with errors"));
+            KSNotification::event(QLatin1String("CalibrationFailed"),
+                                 i18n("Guiding calibration failed with errors"),KSNotification::EVENT_ALERT);
         }
 
         reset();
@@ -857,31 +871,53 @@ bool InternalGuider::processGuiding()
 
     bool sendPulses = true;
 
-    // If within 90% of max pulse repeatedly, let's abort
-    if (out->pulse_length[GUIDE_RA] >= (0.9 * Options::rAMaximumPulse()) ||
-            out->pulse_length[GUIDE_DEC] >= (0.9 * Options::dECMaximumPulse()))
+    // If within 95% of max pulse repeatedly, let's abort
+    if (out->pulse_length[GUIDE_RA] >= (0.95 * Options::rAMaximumPulse()) ||
+        out->pulse_length[GUIDE_DEC] >= (0.95 * Options::dECMaximumPulse()))
     {
-        sendPulses = false;
+        // Stop sending pulses in case we are guiding and we already sent one high pulse before
+        // since we do not want to stray too much off the target to purse the guiding star
+        if (state == GUIDE_GUIDING && m_highPulseCounter > 0)
+            sendPulses = false;
         m_highPulseCounter++;
     }
     else
         m_highPulseCounter=0;
 
-    if (m_starLostCounter+m_highPulseCounter > 3)
+    uint8_t abortThreshold = (state == GUIDE_DITHERING) ? MAX_COMBINTED_PULSE_LIMITS * 3 : MAX_COMBINTED_PULSE_LIMITS;
+    if (m_starLostCounter+m_highPulseCounter > abortThreshold)
     {
+        qCDebug(KSTARS_EKOS_GUIDE) << "m_starLostCounter" << m_starLostCounter
+                                   << "m_highPulseCounter" << m_highPulseCounter;
         emit newLog(i18n("Lost track of the guide star. Searching for guide stars..."));
 
         reacquireTimer.start();
+        rememberState = state;
         state = GUIDE_REACQUIRE;
         emit newStatus(state);
         return true;
     }
 
     if (sendPulses)
+    {
         emit newPulse(out->pulse_dir[GUIDE_RA] , out->pulse_length[GUIDE_RA],
                       out->pulse_dir[GUIDE_DEC], out->pulse_length[GUIDE_DEC]);
 
-    emit frameCaptureRequested();
+        // Wait until pulse is over before capturing an image
+        const int waitMS = qMax(out->pulse_length[GUIDE_RA], out->pulse_length[GUIDE_DEC]);
+        // If less than MAX_IMMEDIATE_CAPTURE ms, then capture immediately
+        if (waitMS > MAX_IMMEDIATE_CAPTURE)
+            // Issue frame requests MAX_IMMEDIATE_CAPTURE ms before timeout to account for
+            // propogation delays
+            QTimer::singleShot(waitMS - PROPAGATION_DELAY, [&]()
+            {
+                emit frameCaptureRequested();
+            });
+        else
+            emit frameCaptureRequested();
+    }
+    else
+        emit frameCaptureRequested();
 
     if (state == GUIDE_DITHERING)
         return true;
@@ -1058,7 +1094,7 @@ bool InternalGuider::selectAutoStar()
                     score -= 1000;
 
                 // Reject stars bigger than square
-                if (center->width > guideBoxSize / subBinX)
+                if (center->width > float(guideBoxSize) / subBinX)
                     score -= 1000;
                 else
                 {
@@ -1135,8 +1171,23 @@ bool InternalGuider::reacquire()
     {
         m_highPulseCounter=m_starLostCounter=0;
         isFirstFrame = true;
-        state = GUIDE_GUIDING;
-        emit newStatus(state);
+        // If we were in the process of dithering, wait until settle and resume
+        if (rememberState == GUIDE_DITHERING)
+        {
+            if (Options::ditherSettle() > 0)
+            {
+                state = GUIDE_DITHERING_SETTLE;
+                emit newStatus(state);
+            }
+
+            QTimer::singleShot(Options::ditherSettle()* 1000, this, SLOT(setDitherSettled()));
+        }
+        else
+        {
+            state = GUIDE_GUIDING;
+            emit newStatus(state);
+        }
+
     }
     else if (reacquireTimer.elapsed() > static_cast<int>(Options::guideLostStarTimeout()*1000))
     {
