@@ -64,7 +64,10 @@ class InternalGuider : public GuideInterface
     bool abort() override;
     bool suspend() override;
     bool resume() override;
+
     bool dither(double pixels) override;
+    bool ditherXY(int x, int y);
+
     bool clearCalibration() override { return true;}
     bool reacquire() override;
 
@@ -171,11 +174,28 @@ class InternalGuider : public GuideInterface
     double phi { 0 };
     uint32_t guideBoxSize { 32 };
 
+    Vector ditherTargetPosition;
+    uint8_t ditherRetries {0};
+
     QTime reacquireTimer;
     int m_highPulseCounter {0};
 
     Ekos::Matrix ROT_Z;
     CalibrationStage calibrationStage { CAL_IDLE };
     CalibrationType calibrationType;
+    Ekos::GuideState rememberState { GUIDE_IDLE };
+
+    // How many high pulses and lost stars before we stop
+    static const uint8_t MAX_COMBINTED_PULSE_LIMITS = 3;
+    // Maximum pulse time limit for immediate capture. Any pulses longer that this
+    // will be delayed until pulse is over
+    static const uint16_t MAX_IMMEDIATE_CAPTURE = 250;
+    // When to start capture before pulse delay is over
+    static const uint16_t PROPAGATION_DELAY = 100;
+
+    // How many 'random' pixels can we move before we have to force direction reversal?
+    static const uint8_t MAX_DITHER_TRAVEL = 25;
+
+    QPair<double,double> accumulator;
 };
 }
