@@ -28,6 +28,7 @@
 #include "ekos/ekosmanager.h"
 
 #include "kstars.h"
+#include "skymapcomposite.h"
 #include "kspaths.h"
 #include "dialogs/finddialog.h"
 #include "kstarsdata.h"
@@ -76,6 +77,17 @@ Mount::Mount()
     updateTimer.setInterval(UPDATE_DELAY);
     connect(&updateTimer, SIGNAL(timeout()), this, SLOT(updateTelescopeCoords()));
 
+    QDateTime now = KStarsData::Instance()->lt();
+    // Set seconds to zero
+    now = now.addSecs(now.time().second()*-1);
+    startupTimeEdit->setDateTime(now);
+
+    connect(&autoParkTimer, &QTimer::timeout, this, &Mount::startAutoPark);
+    connect(startTimerB, &QPushButton::clicked, this, &Mount::startParkTimer);
+    connect(stopTimerB, &QPushButton::clicked, this, &Mount::stopParkTimer);
+
+    stopTimerB->setEnabled(false);
+
     // QML Stuff
     m_BaseView = new QQuickView();
 
@@ -165,6 +177,7 @@ void Mount::setTelescope(ISD::GDInterface *newTelescope)
     connect(currentTelescope, SIGNAL(textUpdated(ITextVectorProperty*)), this,
             SLOT(updateText(ITextVectorProperty*)), Qt::UniqueConnection);
     connect(currentTelescope, SIGNAL(newTarget(QString)), this, SIGNAL(newTarget(QString)), Qt::UniqueConnection);
+    connect(currentTelescope, &ISD::Telescope::slewRateChanged, this, &Mount::slewRateChanged);
     connect(currentTelescope, &ISD::Telescope::Disconnected, [this]()
     {
         updateTimer.stop();
@@ -180,6 +193,10 @@ void Mount::setTelescope(ISD::GDInterface *newTelescope)
     updateTimer.start();
 
     syncTelescopeInfo();
+
+    // Send inital status
+    lastStatus = currentTelescope->getStatus();
+    emit newStatus(lastStatus);
 }
 
 void Mount::syncTelescopeInfo()
@@ -321,8 +338,11 @@ bool Mount::setScopeConfig(int index)
 
 void Mount::updateTelescopeCoords()
 {
-    double ra, dec;
+    // No need to update coords if we are still parked.
+    if (lastStatus == ISD::Telescope::MOUNT_PARKED && lastStatus == currentTelescope->getStatus())
+        return;
 
+    double ra, dec;
     if (currentTelescope && currentTelescope->getEqCoords(&ra, &dec))
     {
         telescopeCoord.setRA(ra);
@@ -442,6 +462,14 @@ void Mount::updateTelescopeCoords()
             updateTimer.stop();
         else if (updateTimer.isActive() == false)
             updateTimer.start();
+
+        // Auto Park Timer
+        if (autoParkTimer.isActive())
+        {
+            QTime remainingTime(0,0,0);
+            remainingTime = remainingTime.addMSecs(autoParkTimer.remainingTime());
+            countdownLabel->setText(remainingTime.toString("hh:mm:ss"));
+        }
     }
     else
         updateTimer.stop();
@@ -674,6 +702,31 @@ bool Mount::isLimitsEnabled()
     return enableLimitsCheck->isChecked();
 }
 
+void Mount::setJ2000Enabled(bool enabled)
+{
+    m_J2000Check->setProperty("checked", enabled);
+}
+
+bool Mount::gotoTarget(const QString &target)
+{
+    SkyObject *object = KStarsData::Instance()->skyComposite()->findByName(target);
+
+    if (object != nullptr)
+        return slew(object->ra().Hours(), object->dec().Degrees());
+
+    return false;
+}
+
+bool Mount::syncTarget(const QString &target)
+{
+    SkyObject *object = KStarsData::Instance()->skyComposite()->findByName(target);
+
+    if (object != nullptr)
+        return sync(object->ra().Hours(), object->dec().Degrees());
+
+    return false;
+}
+
 bool Mount::slew(const QString &RA, const QString &DEC)
 {
     dms ra, de;
@@ -1012,4 +1065,109 @@ void Mount::syncGPS()
         }
     }
 }
+
+void Mount::setTrackEnabled(bool enabled)
+{
+    if (enabled)
+        trackOnB->click();
+    else
+        trackOffB->click();
+}
+
+int Mount::getSlewRate()
+{
+    if (currentTelescope == nullptr)
+        return -1;
+
+    return currentTelescope->getSlewRate();
+}
+
+QJsonArray Mount::getScopes() const
+{
+    QJsonArray scopes;
+    if (currentTelescope == nullptr)
+        return scopes;
+
+    QJsonObject primary = {
+      {"name", "Primary"},
+      {"mount", currentTelescope->getDeviceName()},
+      {"aperture", primaryScopeApertureIN->value()},
+      {"focalLength", primaryScopeFocalIN->value()},
+    };
+
+    scopes.append(primary);
+
+    QJsonObject guide = {
+      {"name", "Guide"},
+      {"mount", currentTelescope->getDeviceName()},
+      {"aperture", primaryScopeApertureIN->value()},
+      {"focalLength", primaryScopeFocalIN->value()},
+    };
+
+    scopes.append(guide);
+
+    return scopes;
+}
+
+void Mount::startParkTimer()
+{
+    if (currentTelescope == nullptr)
+        return;
+
+    if (currentTelescope->isParked())
+    {
+        appendLogText("Mount already parked.");
+        return;
+    }
+
+    QDateTime parkTime = startupTimeEdit->dateTime();
+    qint64 parkSeconds = parkTime.msecsTo(KStarsData::Instance()->lt());
+    if (parkSeconds > 0)
+    {
+        appendLogText(i18n("Parking time cannot be in the past!"));
+        return;
+    }
+
+    parkSeconds = std::abs(parkSeconds);
+
+    if (parkSeconds > 24*60*60*1000)
+    {
+        appendLogText(i18n("Parking time must be within 24 hours of current time."));
+        return;
+    }
+
+    appendLogText(i18n("Caution! Do not use Auto Park while scheduler is active."));
+
+    autoParkTimer.setInterval(parkSeconds);
+    autoParkTimer.start();
+
+    startTimerB->setEnabled(false);
+    stopTimerB->setEnabled(true);
+}
+
+void Mount::stopParkTimer()
+{
+    autoParkTimer.stop();
+    countdownLabel->setText("00:00:00");
+    stopTimerB->setEnabled(false);
+    startTimerB->setEnabled(true);
+}
+
+void Mount::startAutoPark()
+{
+    appendLogText(i18n("Parking timer is up."));
+    autoParkTimer.stop();
+    startTimerB->setEnabled(true);
+    stopTimerB->setEnabled(false);
+    countdownLabel->setText("00:00:00");
+    if (currentTelescope)
+    {
+        if (currentTelescope->isParked() == false)
+        {
+            appendLogText(i18n("Starting auto park..."));
+            park();
+        }
+    }
+}
+
 }
