@@ -52,11 +52,13 @@ ProfileEditor::ProfileEditor(QWidget *w) : QDialog(w)
         QDesktopServices::openUrl(url);
     });
 
-    connect(ui->INDIWebManagerCheck, SIGNAL(toggled(bool)), ui->openWebManagerB, SLOT(setEnabled(bool)));
+    connect(ui->INDIWebManagerCheck, &QCheckBox::toggled, [&](bool enabled) {
+        ui->openWebManagerB->setEnabled(enabled);
+        ui->remoteDrivers->setEnabled(enabled || ui->localMode->isChecked());
+    });
 
     connect(ui->guideTypeCombo, SIGNAL(activated(int)), this, SLOT(updateGuiderSelection(int)));
 
-    ui->addScopeB->setIcon(QIcon::fromTheme("list-add"));
     connect(ui->addScopeB, &QPushButton::clicked, this, [this]()
     {
         QPointer<EquipmentWriter> equipmentdlg = new EquipmentWriter();
@@ -64,7 +66,7 @@ ProfileEditor::ProfileEditor(QWidget *w) : QDialog(w)
         equipmentdlg->exec();
         delete equipmentdlg;
         loadScopeEquipment();
-    });
+    });    
 
 #ifdef Q_OS_WIN
     ui->remoteMode->setChecked(true);
@@ -80,10 +82,6 @@ ProfileEditor::ProfileEditor(QWidget *w) : QDialog(w)
     loadScopeEquipment();
 }
 
-ProfileEditor::~ProfileEditor()
-{
-}
-
 void ProfileEditor::loadScopeEquipment()
 {
     // Get all OAL equipment filter list
@@ -283,6 +281,8 @@ void ProfileEditor::saveProfile()
     else
         pi->drivers["Aux4"] = ui->aux4Combo->currentText();
 
+    pi->remotedrivers = ui->remoteDrivers->text();
+
     KStarsData::Instance()->userdb()->SaveProfile(pi);
 
     // Ekos manager will reload and new profiles will be created
@@ -317,6 +317,8 @@ void ProfileEditor::setRemoteMode(bool enable)
     ui->aux3Combo->setEditable(enable);
     ui->aux4Combo->setEditable(enable);
 
+    ui->remoteDrivers->setEnabled(!enable);
+
     ui->loadSiteCheck->setEnabled(enable);
 
     ui->INDIWebManagerCheck->setEnabled(enable);
@@ -362,6 +364,9 @@ void ProfileEditor::setPi(ProfileInfo *value)
         }
     }
 
+    if (pi->remotedrivers.isEmpty() == false)
+        ui->remoteDrivers->setText(pi->remotedrivers);
+
     ui->guideTypeCombo->setCurrentIndex(pi->guidertype);
     updateGuiderSelection(ui->guideTypeCombo->currentIndex());
     if (pi->guidertype == Ekos::Guide::GUIDE_PHD2)
@@ -538,7 +543,7 @@ void ProfileEditor::loadDrivers()
         box->setMaxVisibleItems(20);
     }
 
-    QIcon remoteIcon = QIcon::fromTheme("modem");
+    QIcon remoteIcon = QIcon::fromTheme("network-modem");
 
     foreach (DriverInfo *dv, DriverManager::Instance()->getDrivers())
     {
@@ -560,129 +565,130 @@ void ProfileEditor::loadDrivers()
                 "<nobr>Available as <b>Remote</b> Driver. To use locally, install the corresponding driver.<nobr/>");
         else
             toolTipText = i18n("<nobr><b>Label</b>: %1 &#9473; <b>Driver</b>: %2 &#9473; <b>Exec</b>: %3<nobr/>",
-                               dv->getTreeLabel(), dv->getName(), dv->getDriver());
+                               dv->getLabel(), dv->getName(), dv->getExecutable());
 
         switch (dv->getType())
         {
             case KSTARS_TELESCOPE:
             {
-                ui->mountCombo->addItem(icon, dv->getTreeLabel());
+                ui->mountCombo->addItem(icon, dv->getLabel());
                 ui->mountCombo->setItemData(ui->mountCombo->count() - 1, toolTipText, Qt::ToolTipRole);
             }
             break;
 
             case KSTARS_CCD:
             {
-                ui->ccdCombo->addItem(icon, dv->getTreeLabel());
+                ui->ccdCombo->addItem(icon, dv->getLabel());
                 ui->ccdCombo->setItemData(ui->ccdCombo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->guiderCombo->addItem(icon, dv->getTreeLabel());
+                ui->guiderCombo->addItem(icon, dv->getLabel());
                 ui->guiderCombo->setItemData(ui->guiderCombo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux1Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux1Combo->addItem(icon, dv->getLabel());
                 ui->aux1Combo->setItemData(ui->aux1Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux2Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux2Combo->addItem(icon, dv->getLabel());
                 ui->aux2Combo->setItemData(ui->aux2Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux3Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux3Combo->addItem(icon, dv->getLabel());
                 ui->aux3Combo->setItemData(ui->aux3Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux4Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux4Combo->addItem(icon, dv->getLabel());
                 ui->aux4Combo->setItemData(ui->aux4Combo->count() - 1, toolTipText, Qt::ToolTipRole);
             }
             break;
 
             case KSTARS_ADAPTIVE_OPTICS:
             {
-                ui->AOCombo->addItem(icon, dv->getTreeLabel());
+                ui->AOCombo->addItem(icon, dv->getLabel());
                 ui->AOCombo->setItemData(ui->AOCombo->count() - 1, toolTipText, Qt::ToolTipRole);
             }
             break;
 
             case KSTARS_FOCUSER:
             {
-                ui->focuserCombo->addItem(icon, dv->getTreeLabel());
+                ui->focuserCombo->addItem(icon, dv->getLabel());
                 ui->focuserCombo->setItemData(ui->focuserCombo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux1Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux1Combo->addItem(icon, dv->getLabel());
                 ui->aux1Combo->setItemData(ui->aux1Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux2Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux2Combo->addItem(icon, dv->getLabel());
                 ui->aux2Combo->setItemData(ui->aux2Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux3Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux3Combo->addItem(icon, dv->getLabel());
                 ui->aux3Combo->setItemData(ui->aux3Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux4Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux4Combo->addItem(icon, dv->getLabel());
                 ui->aux4Combo->setItemData(ui->aux4Combo->count() - 1, toolTipText, Qt::ToolTipRole);
             }
             break;
 
             case KSTARS_FILTER:
             {
-                ui->filterCombo->addItem(icon, dv->getTreeLabel());
+                ui->filterCombo->addItem(icon, dv->getLabel());
                 ui->filterCombo->setItemData(ui->filterCombo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux1Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux1Combo->addItem(icon, dv->getLabel());
                 ui->aux1Combo->setItemData(ui->aux1Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux2Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux2Combo->addItem(icon, dv->getLabel());
                 ui->aux2Combo->setItemData(ui->aux2Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux3Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux3Combo->addItem(icon, dv->getLabel());
                 ui->aux3Combo->setItemData(ui->aux3Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux4Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux4Combo->addItem(icon, dv->getLabel());
                 ui->aux4Combo->setItemData(ui->aux4Combo->count() - 1, toolTipText, Qt::ToolTipRole);
             }
             break;
 
             case KSTARS_DOME:
             {
-                ui->domeCombo->addItem(icon, dv->getTreeLabel());
+                ui->domeCombo->addItem(icon, dv->getLabel());
                 ui->domeCombo->setItemData(ui->domeCombo->count() - 1, toolTipText, Qt::ToolTipRole);
             }
             break;
 
             case KSTARS_WEATHER:
             {
-                ui->weatherCombo->addItem(icon, dv->getTreeLabel());
+                ui->weatherCombo->addItem(icon, dv->getLabel());
                 ui->weatherCombo->setItemData(ui->weatherCombo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux1Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux1Combo->addItem(icon, dv->getLabel());
                 ui->aux1Combo->setItemData(ui->aux1Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux2Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux2Combo->addItem(icon, dv->getLabel());
                 ui->aux2Combo->setItemData(ui->aux2Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux3Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux3Combo->addItem(icon, dv->getLabel());
                 ui->aux3Combo->setItemData(ui->aux3Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux4Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux4Combo->addItem(icon, dv->getLabel());
                 ui->aux4Combo->setItemData(ui->aux4Combo->count() - 1, toolTipText, Qt::ToolTipRole);
             }
             break;
 
             case KSTARS_AUXILIARY:
+            case KSTARS_SPECTROGRAPHS:
+            case KSTARS_DETECTORS:
             {
-                ui->aux1Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux1Combo->addItem(icon, dv->getLabel());
                 ui->aux1Combo->setItemData(ui->aux1Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux2Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux2Combo->addItem(icon, dv->getLabel());
                 ui->aux2Combo->setItemData(ui->aux2Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux3Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux3Combo->addItem(icon, dv->getLabel());
                 ui->aux3Combo->setItemData(ui->aux3Combo->count() - 1, toolTipText, Qt::ToolTipRole);
 
-                ui->aux4Combo->addItem(icon, dv->getTreeLabel());
+                ui->aux4Combo->addItem(icon, dv->getLabel());
                 ui->aux4Combo->setItemData(ui->aux4Combo->count() - 1, toolTipText, Qt::ToolTipRole);
             }
             break;
 
             default:
                 continue;
-                break;
         }
     }
 
@@ -778,6 +784,7 @@ void ProfileEditor::setConnectionOptionsEnabled(bool enable)
     ui->INDIWebManagerPortLabel->setEnabled(enable);
     ui->guidingTypeLabel->setEnabled(enable);
     ui->guideTypeCombo->setEnabled(enable);
+    ui->remoteDrivers->setEnabled(enable);
 
     updateGuiderSelection(ui->guideTypeCombo->currentIndex());
 
