@@ -22,7 +22,7 @@
 #include <QUrl>
 #include <QtDBus/QtDBus>
 
-#include <stdint.h>
+#include <cstdint>
 
 class QProgressIndicator;
 
@@ -542,6 +542,11 @@ class Scheduler : public QWidget, public Ui::Scheduler
          */
     bool createJobSequence(XMLEle *root, const QString &prefix, const QString &outputDir);
 
+    /** @internal Change the current job, updating associated widgets.
+     * @param job is an existing SchedulerJob to set as current, or nullptr.
+     */
+    void setCurrentJob(SchedulerJob *job);
+
     void loadProfiles();
 
     XMLEle *getSequenceJobRoot();
