@@ -8,19 +8,15 @@
  */
 
 #include "schedulerjob.h"
-#include "scheduler.h"
 
 #include "dms.h"
 #include "kstarsdata.h"
+#include "scheduler.h"
 
 #include <knotification.h>
 
 #include <QTableWidgetItem>
 
-SchedulerJob::SchedulerJob()
-{
-}
-
 void SchedulerJob::setName(const QString &value)
 {
     name = value;
@@ -389,7 +385,7 @@ void SchedulerJob::updateJobCell()
         }
         if (stageLabel)
         {
-            stageLabel->setText(QString("%1: %2").arg(name).arg(stageStrings.value(stage, stageStringUnknown)));
+            stageLabel->setText(QString("%1: %2").arg(name, stageStrings.value(stage, stageStringUnknown)));
         }
     }
 
