@@ -21,6 +21,7 @@
 #include <QUndoStack>
 #include <QUrl>
 #include <QWidget>
+#include <QFuture>
 
 #include <memory>
 
@@ -94,6 +95,9 @@ class FITSTab : public QWidget
     QString previewText;
     int uid { 0 };
 
+    QFuture<void> histogramFuture;
+
+
   signals:
     void debayerToggled(bool);
     void newStatus(const QString &msg, FITSBar id);
