@@ -82,7 +82,7 @@ FITSView::~FITSView()
     wcsWatcher.waitForFinished();
 
     delete (imageData);
-    delete (display_image);
+    delete (displayImage);
 }
 
 /**
@@ -273,6 +273,10 @@ bool FITSView::loadFITS(const QString &inFilename, bool silent)
         QTimer::singleShot(100 , this , SLOT(viewStarProfile()));  //Need to wait till the Focus module finds stars, if its the Focus module.
     }
 
+    updateFrame();
+
+    emit imageLoaded();
+
     return true;
 }
 
@@ -369,20 +373,20 @@ int FITSView::rescale(FITSZoom type)
     double min, max;
     bool displayBuffer = false;
 
-    if (display_image == nullptr)
+    if (displayImage == nullptr)
         return -1;
 
     uint8_t *image_buffer = imageData->getImageBuffer();
 
-    uint32_t size = imageData->getSize();
+    uint32_t size = imageData->getSamplesPerChannel();
     int BBP       = imageData->getBytesPerPixel();
 
     filter = filterStack.last();
 
     if (Options::autoStretch() && (filter == FITS_NONE || (filter >= FITS_ROTATE_CW && filter <= FITS_FLIP_V)))
     {
-        image_buffer = new uint8_t[imageData->getSize() * imageData->getNumOfChannels() * BBP];
-        memcpy(image_buffer, imageData->getImageBuffer(), imageData->getSize() * imageData->getNumOfChannels() * BBP);
+        image_buffer = new uint8_t[imageData->getSamplesPerChannel() * imageData->getNumOfChannels() * BBP];
+        memcpy(image_buffer, imageData->getImageBuffer(), imageData->getSamplesPerChannel() * imageData->getNumOfChannels() * BBP);
 
         displayBuffer = true;
 
@@ -404,7 +408,7 @@ int FITSView::rescale(FITSZoom type)
 
     if (min == max)
     {
-        display_image->fill(Qt::white);
+        displayImage->fill(Qt::white);
         emit newStatus(i18n("Image is saturated!"), FITS_MESSAGE);
     }
     else
@@ -424,12 +428,12 @@ int FITSView::rescale(FITSZoom type)
         }
 
         image_frame->setScaledContents(true);
-        currentWidth  = display_image->width();
-        currentHeight = display_image->height();
+        currentWidth  = displayImage->width();
+        currentHeight = displayImage->height();
 
         if (imageData->getNumOfChannels() == 1)
         {
-            QList<QFuture<void>> futures;
+            QVector<QFuture<void>> futures;
 
             /* Fill in pixel values using indexed map, linear scale */
             for (uint32_t j = 0; j < image_height; j++)
@@ -437,7 +441,7 @@ int FITSView::rescale(FITSZoom type)
                 futures.append(QtConcurrent::run([=]()
                 {
                     T *runningBuffer = buffer +j*image_width;
-                    uint8_t *scanLine = display_image->scanLine(j);
+                    uint8_t *scanLine = displayImage->scanLine(j);
                     for (uint32_t i = 0; i < image_width; i++)
                     {
                         //scanLine[i] = qBound(0, static_cast<uint8_t>(runningBuffer[i] * bscale + bzero), 255);
@@ -451,13 +455,14 @@ int FITSView::rescale(FITSZoom type)
         }
         else
         {
-            QList<QFuture<void>> futures;
+            QVector<QFuture<void>> futures;
+
             /* Fill in pixel values using indexed map, linear scale */
             for (uint32_t j = 0; j < image_height; j++)
             {                
                 futures.append(QtConcurrent::run([=]()
                 {
-                    auto *scanLine = reinterpret_cast<QRgb *>((display_image->scanLine(j)));
+                    auto *scanLine = reinterpret_cast<QRgb *>((displayImage->scanLine(j)));
                     T *runningBufferR = buffer + j*image_width;
                     T *runningBufferG = buffer + j*image_width + size;
                     T *runningBufferB = buffer + j*image_width + size*2;
@@ -520,7 +525,7 @@ int FITSView::rescale(FITSZoom type)
     switch (type)
     {
         case ZOOM_FIT_WINDOW:
-            if ((display_image->width() > width() || display_image->height() > height()))
+            if ((displayImage->width() > width() || displayImage->height() > height()))
             {
                 double w = baseSize().width() - BASE_OFFSET;
                 double h = baseSize().height() - BASE_OFFSET;
@@ -624,7 +629,7 @@ void FITSView::ZoomOut()
 
 void FITSView::ZoomToFit()
 {
-    if (display_image != nullptr)
+    if (displayImage != nullptr)
     {
         rescale(ZOOM_FIT_WINDOW);
         updateFrame();
@@ -632,18 +637,17 @@ void FITSView::ZoomToFit()
 }
 
 void FITSView::updateFrame()
-{
-    QPixmap displayPixmap;
+{    
     bool ok = false;
 
-    if (display_image == nullptr)
+    if (displayImage == nullptr)
         return;
 
     if (currentZoom != ZOOM_DEFAULT)
         ok = displayPixmap.convertFromImage(
-            display_image->scaled(currentWidth, currentHeight, Qt::KeepAspectRatio, Qt::SmoothTransformation));
+            displayImage->scaled(currentWidth, currentHeight, Qt::KeepAspectRatio, Qt::SmoothTransformation));
     else
-        ok = displayPixmap.convertFromImage(*display_image);
+        ok = displayPixmap.convertFromImage(*displayImage);
 
     if (!ok)
         return;
@@ -979,7 +983,7 @@ void FITSView::drawEQGrid(QPainter *painter)
                         if (maxDec > 50 || maxDec < -50)
                             painter->drawText(pt.x(), pt.y(),
                                               QString::number(dms(target).hour()) + "h " +
-                                                  QString::number(dms(target).minute()) + "'");
+                                                  QString::number(dms(target).minute()) + '\'');
                         else
                             painter->drawText(pt.x() - 20, pt.y(),
                                               QString::number(dms(target).hour()) + "h " +
@@ -1018,7 +1022,7 @@ void FITSView::drawEQGrid(QPainter *painter)
                     if (pt.x() != -100)
                         painter->drawText(pt.x(), pt.y(),
                                           QString::number(dms(target).degree()) + "° " +
-                                              QString::number(dms(target).arcmin()) + "'");
+                                              QString::number(dms(target).arcmin()) + '\'');
                 }
             }
 
@@ -1138,15 +1142,15 @@ void FITSView::setFirstLoad(bool value)
     firstLoad = value;
 }
 
-QPixmap &FITSView::getTrackingBoxPixmap()
+QPixmap &FITSView::getTrackingBoxPixmap(uint8_t margin)
 {
     if (trackingBox.isNull())
         return trackingBoxPixmap;
 
-    int x1 = trackingBox.x() * (currentZoom / ZOOM_DEFAULT);
-    int y1 = trackingBox.y() * (currentZoom / ZOOM_DEFAULT);
-    int w  = trackingBox.width() * (currentZoom / ZOOM_DEFAULT);
-    int h  = trackingBox.height() * (currentZoom / ZOOM_DEFAULT);
+    int x1 = (trackingBox.x() - margin) * (currentZoom / ZOOM_DEFAULT);
+    int y1 = (trackingBox.y() - margin) * (currentZoom / ZOOM_DEFAULT);
+    int w  = (trackingBox.width() + margin*2) * (currentZoom / ZOOM_DEFAULT);
+    int h  = (trackingBox.height() + margin*2) * (currentZoom / ZOOM_DEFAULT);
 
     trackingBoxPixmap = image_frame->grab(QRect(x1, y1, w, h));
 
@@ -1462,20 +1466,20 @@ QPoint FITSView::getImagePoint(QPoint viewPortPoint)
 
 void FITSView::initDisplayImage()
 {
-    delete display_image;
-    display_image = nullptr;
+    delete displayImage;
+    displayImage = nullptr;
 
     if (imageData->getNumOfChannels() == 1)
     {
-        display_image = new QImage(image_width, image_height, QImage::Format_Indexed8);
+        displayImage = new QImage(image_width, image_height, QImage::Format_Indexed8);
 
-        display_image->setColorCount(256);
+        displayImage->setColorCount(256);
         for (int i = 0; i < 256; i++)
-            display_image->setColor(i, qRgb(i, i, i));
+            displayImage->setColor(i, qRgb(i, i, i));
     }
     else
     {
-        display_image = new QImage(image_width, image_height, QImage::Format_RGB32);
+        displayImage = new QImage(image_width, image_height, QImage::Format_RGB32);
     }
 }
 
