@@ -35,8 +35,6 @@
 ScanRender::ScanRender(void)
 //////////////////////////////
 {
-  bBilinear = false;
-  m_opacity = 1.f;
 }
 
 /////////////////////////////////////////////////
