@@ -19,14 +19,6 @@
 
 #include <indi_debug.h>
 
-ClientManager::ClientManager()
-{
-}
-
-ClientManager::~ClientManager()
-{
-}
-
 bool ClientManager::isDriverManaged(DriverInfo *di)
 {
     foreach (DriverInfo *dv, managedDrivers)
@@ -89,7 +81,6 @@ void ClientManager::newDevice(INDI::BaseDevice *dp)
     DeviceInfo *devInfo = new DeviceInfo(deviceDriver, dp);
     deviceDriver->addDevice(devInfo);
     emit newINDIDevice(devInfo);
-    return;
 }
 
 void ClientManager::newProperty(INDI::Property *prop)
@@ -252,7 +243,7 @@ DriverInfo *ClientManager::findDriverInfoByLabel(const QString &label)
 {
     foreach (DriverInfo *dv, managedDrivers)
     {
-        if (dv->getTreeLabel() == label)
+        if (dv->getLabel() == label)
             return dv;
     }
 
