@@ -16,9 +16,10 @@
 #include "Options.h"
 #include "skymap.h"
 #include "skymapcomposite.h"
+#include "ksnotification.h"
 
-#include <KNotification>
 #include <KActionCollection>
+
 #include <QAction>
 
 #include <indi_debug.h>
@@ -39,10 +40,6 @@ Telescope::Telescope(GDInterface *iPtr) : DeviceDecorator(iPtr)
     connect(centerLockTimer, &QTimer::timeout, this, [this]() { runCommand(INDI_CENTER_LOCK); });
 }
 
-Telescope::~Telescope()
-{
-}
-
 void Telescope::registerProperty(INDI::Property *prop)
 {
     if (!strcmp(prop->getName(), "TELESCOPE_INFO"))
@@ -136,6 +133,17 @@ void Telescope::registerProperty(INDI::Property *prop)
         m_hasCustomTrackRate = true;
     else if (!strcmp(prop->getName(), "TELESCOPE_PARK_OPTION"))
         m_hasCustomParking = true;
+    else if (!strcmp(prop->getName(), "TELESCOPE_SLEW_RATE"))
+    {
+        m_hasSlewRates = true;
+        ISwitchVectorProperty *svp = prop->getSwitch();
+        if (svp)
+        {
+            m_slewRates.clear();
+            for (int i=0; i < svp->nsp; i++)
+                m_slewRates << svp->sp[i].label;
+        }
+    }
 
     DeviceDecorator::registerProperty(prop);
 }
@@ -158,11 +166,11 @@ void Telescope::processNumber(INumberVectorProperty *nvp)
         if (nvp->s == IPS_BUSY && EqCoordPreviousState != IPS_BUSY)
         {
             if (getStatus() != MOUNT_PARKING)
-                KNotification::event(QLatin1String("SlewStarted"), i18n("Mount is slewing to target location"));
+                KSNotification::event(QLatin1String("SlewStarted"), i18n("Mount is slewing to target location"));
         }
         else if (EqCoordPreviousState == IPS_BUSY && nvp->s == IPS_OK)
         {
-            KNotification::event(QLatin1String("SlewCompleted"), i18n("Mount arrived at target location"));
+            KSNotification::event(QLatin1String("SlewCompleted"), i18n("Mount arrived at target location"));
 
             double maxrad = 1000.0 / Options::zoomFactor();
 
@@ -204,7 +212,7 @@ void Telescope::processSwitch(ISwitchVectorProperty *svp)
         if (conSP)
         {
             // TODO We must allow for multiple mount drivers to be online, not just one
-            // For the actions taken, the user should be able to specifiy which mounts shall receive the commands. It could be one
+            // For the actions taken, the user should be able to specify which mounts shall receive the commands. It could be one
             // or more. For now, we enable/disable telescope group on the assumption there is only one mount present.
             if (isConnected() == false && conSP->s == ISS_ON)
                 KStars::Instance()->slotSetTelescopeEnabled(true);
@@ -229,23 +237,23 @@ void Telescope::processSwitch(ISwitchVectorProperty *svp)
                 else if (parkStatus == PARK_UNPARKING)
                     parkStatus = PARK_PARKED;
 
-                KNotification::event(QLatin1String("MountParkingFailed"), i18n("Mount parking failed"));
+                KSNotification::event(QLatin1String("MountParkingFailed"), i18n("Mount parking failed"), KSNotification::EVENT_ALERT);
             }
             else if (svp->s == IPS_BUSY && sp->s == ISS_ON && parkStatus != PARK_PARKING)
             {
                 parkStatus = PARK_PARKING;
-                KNotification::event(QLatin1String("MountParking"), i18n("Mount parking is in progress"));
+                KSNotification::event(QLatin1String("MountParking"), i18n("Mount parking is in progress"));
                 currentObject = nullptr;
             }
             else if (svp->s == IPS_BUSY && sp->s == ISS_OFF && parkStatus != PARK_UNPARKING)
             {
                 parkStatus = PARK_UNPARKING;
-                KNotification::event(QLatin1String("MountUnParking"), i18n("Mount unparking is in progress"));
+                KSNotification::event(QLatin1String("MountUnParking"), i18n("Mount unparking is in progress"));
             }
             else if (svp->s == IPS_OK && sp->s == ISS_ON && parkStatus != PARK_PARKED)
             {
                 parkStatus = PARK_PARKED;
-                KNotification::event(QLatin1String("MountParked"), i18n("Mount parked"));
+                KSNotification::event(QLatin1String("MountParked"), i18n("Mount parked"));
                 currentObject = nullptr;
 
                 QAction *parkAction = KStars::Instance()->actionCollection()->action("telescope_park");
@@ -254,11 +262,13 @@ void Telescope::processSwitch(ISwitchVectorProperty *svp)
                 QAction *unParkAction = KStars::Instance()->actionCollection()->action("telescope_unpark");
                 if (unParkAction)
                     unParkAction->setEnabled(true);
+
+                emit newTarget(QString());
             }
             else if ( (svp->s == IPS_OK || svp->s == IPS_IDLE) && sp->s == ISS_OFF && parkStatus != PARK_UNPARKED)
             {
                 parkStatus = PARK_UNPARKED;
-                KNotification::event(QLatin1String("MountUnparked"), i18n("Mount unparked"));
+                KSNotification::event(QLatin1String("MountUnparked"), i18n("Mount unparked"));
                 currentObject = nullptr;
 
                 QAction *parkAction = KStars::Instance()->actionCollection()->action("telescope_park");
@@ -275,7 +285,7 @@ void Telescope::processSwitch(ISwitchVectorProperty *svp)
         if (svp->s == IPS_OK)
         {
             inCustomParking = false;
-            KNotification::event(QLatin1String("MountAborted"), i18n("Mount motion was aborted"));
+            KSNotification::event(QLatin1String("MountAborted"), i18n("Mount motion was aborted"), KSNotification::EVENT_WARN);
         }
     }
     else if (!strcmp(svp->name, "TELESCOPE_MOTION_NS"))
@@ -299,13 +309,13 @@ void Telescope::processSwitch(ISwitchVectorProperty *svp)
                                             (WECurrentMotion == IPS_BUSY && WEPreviousState != IPS_BUSY)))
             {
                 inManualMotion = true;
-                KNotification::event(QLatin1String("MotionStarted"), i18n("Mount is manually moving"));
+                KSNotification::event(QLatin1String("MotionStarted"), i18n("Mount is manually moving"));
             }
             else if (inManualMotion && ((NSCurrentMotion != IPS_BUSY && NSPreviousState == IPS_BUSY) ||
                                         (WECurrentMotion != IPS_BUSY && WEPreviousState == IPS_BUSY)))
             {
                 inManualMotion = false;
-                KNotification::event(QLatin1String("MotionStopped"), i18n("Mount is manually moving"));
+                KSNotification::event(QLatin1String("MotionStopped"), i18n("Mount motion stopped"));
             }
 
             NSPreviousState = NSCurrentMotion;
@@ -887,6 +897,8 @@ bool Telescope::setSlewRate(int index)
 
     if (index < 0 || index > slewRateSP->nsp)
         return false;
+    else if (IUFindOnSwitchIndex(slewRateSP) == index)
+        return true;
 
     IUResetSwitch(slewRateSP);
 
@@ -894,9 +906,21 @@ bool Telescope::setSlewRate(int index)
 
     clientManager->sendNewSwitch(slewRateSP);
 
+    emit slewRateChanged(index);
+
     return true;
 }
 
+int Telescope::getSlewRate() const
+{
+    ISwitchVectorProperty *slewRateSP = baseDevice->getSwitch("TELESCOPE_SLEW_RATE");
+
+    if (slewRateSP == nullptr)
+        return -1;
+
+    return IUFindOnSwitchIndex(slewRateSP);
+}
+
 void Telescope::setAltLimits(double minAltitude, double maxAltitude)
 {
     minAlt = minAltitude;
