@@ -112,6 +112,45 @@ bool isOnline(ProfileInfo *pi)
         return false;
 }
 
+bool syncCustomDrivers(ProfileInfo *pi)
+{
+    QNetworkAccessManager manager;
+    QUrl url(QString("http://%1:%2/api/profiles/custom").arg(pi->host).arg(pi->INDIWebManagerPort));
+
+    QStringList customDriversLabels;
+    QMapIterator<QString, QString> i(pi->drivers);
+    while (i.hasNext())
+    {
+        QString name       = i.next().value();
+        DriverInfo *driver = DriverManager::Instance()->findDriverByName(name);
+
+        if (driver == nullptr)
+            driver = DriverManager::Instance()->findDriverByLabel(name);
+        if (driver && driver->getDriverSource() == CUSTOM_SOURCE)
+            customDriversLabels << driver->getLabel();
+    }
+
+    // Search for locked filter by filter color name
+    const QList<QVariantMap> &customDrivers = DriverManager::Instance()->getCustomDrivers();
+
+    for (auto label : customDriversLabels)
+    {
+        auto pos = std::find_if(customDrivers.begin(), customDrivers.end(), [label](QVariantMap oneDriver)
+        {return (oneDriver["Label"] == label);});
+
+        if (pos == customDrivers.end())
+            continue;
+
+        QVariantMap driver = (*pos);
+        QJsonObject jsonDriver = QJsonObject::fromVariantMap(driver);
+
+        QByteArray data    = QJsonDocument(jsonDriver).toJson();
+        getWebManagerResponse(QNetworkAccessManager::PostOperation, url, nullptr, &data);
+    }
+
+    return true;
+}
+
 bool areDriversRunning(ProfileInfo *pi)
 {
     QUrl url(QString("http://%1:%2/api/server/drivers").arg(pi->host).arg(pi->INDIWebManagerPort));
@@ -134,7 +173,7 @@ bool areDriversRunning(ProfileInfo *pi)
             if (driver == nullptr)
                 driver = DriverManager::Instance()->findDriverByLabel(name);
             if (driver)
-                piExecDrivers << driver->getDriver();
+                piExecDrivers << driver->getExecutable();
         }
 
         if (array.count() < piExecDrivers.count())
@@ -144,12 +183,17 @@ bool areDriversRunning(ProfileInfo *pi)
         QStringList webManagerDrivers;
         for (auto value : array)
         {
-            QJsonObject obj = value.toObject();
-            webManagerDrivers << obj.value("driver").toString();
+            QJsonObject driver = value.toObject();
+            // Old Web Manager API API
+            QString exec = driver["driver"].toString();
+            if (exec.isEmpty())
+                // New v0.1.5+ Web Manager API
+                exec = driver["binary"].toString();
+            webManagerDrivers << exec;
         }
 
         // Make sure all the profile drivers are running there
-        for (auto oneDriverExec : piExecDrivers)
+        for (auto &oneDriverExec : piExecDrivers)
         {
             if (webManagerDrivers.contains(oneDriverExec) == false)
             {
@@ -211,11 +255,21 @@ bool syncProfile(ProfileInfo *pi)
         }
     }
 
+    // Regular Drivers
     while (i.hasNext())
         driverArray.append(QJsonObject({{"label", i.next().value()}}));
 
+    // Remote Drivers
+    if (pi->remotedrivers.isEmpty() == false)
+    {
+        for (auto remoteDriver : pi->remotedrivers.split(","))
+        {
+            driverArray.append(QJsonObject({{"remote", remoteDriver}}));
+        }
+    }
+
     data    = QJsonDocument(driverArray).toJson();
-    getWebManagerResponse(QNetworkAccessManager::PostOperation, url, nullptr, &data);
+    getWebManagerResponse(QNetworkAccessManager::PostOperation, url, nullptr, &data);        
 
     return true;
 }
