@@ -16,11 +16,11 @@
  ***************************************************************************/
 
 #include "kstars.h"
-#include "kstars_debug.h"
 
 #include "fov.h"
 #include "kspaths.h"
 #include "kstarsdata.h"
+#include "kstars_debug.h"
 #include "Options.h"
 #include "skymap.h"
 #include "texturemanager.h"
@@ -350,7 +350,7 @@ void KStars::initActions()
 
     //Add HIPS Sources actions
     hipsActionMenu = actionCollection()->add<KActionMenu>("hipssources");
-    hipsActionMenu->setText(i18n("HiPS All Sky Overlay (Experimental)"));
+    hipsActionMenu->setText(i18n("HiPS All Sky Overlay"));
     hipsActionMenu->setDelayed(false);
     hipsActionMenu->setIcon(QIcon::fromTheme("view-preview"));
     HIPSManager::Instance()->readSources();
@@ -465,14 +465,19 @@ void KStars::initActions()
 // ==== devices Menu ================
 #ifdef HAVE_INDI
 #ifndef Q_OS_WIN
+#if 0
     actionCollection()->addAction("telescope_wizard", this, SLOT(slotTelescopeWizard()))
         << i18n("Telescope Wizard...")
         << QIcon::fromTheme("tools-wizard");
+#endif
 #endif
     actionCollection()->addAction("device_manager", this, SLOT(slotINDIDriver()))
         << i18n("Device Manager...")
         << QIcon::fromTheme("network-server")
         << QKeySequence(Qt::SHIFT + Qt::META + Qt::Key_D);
+    actionCollection()->addAction("custom_drivers", DriverManager::Instance(), SLOT(showCustomDrivers()))
+        << i18n("Custom Drivers...")
+        << QIcon::fromTheme("address-book-new");
     ka = actionCollection()->addAction("indi_cpl", this, SLOT(slotINDIPanel()))
         << i18n("INDI Control Panel...")
         << QKeySequence(Qt::CTRL + Qt::Key_I);
@@ -682,8 +687,12 @@ void KStars::repopulateFOV()
 void KStars::repopulateHIPS()
 {
     // Iterate through actions
-    hipsActionMenu->menu()->clear();    
-    hipsGroup->actions().clear();    
+    hipsActionMenu->menu()->clear();
+    // Remove all actions
+    QList<QAction*> actions = hipsGroup->actions();
+
+    for (auto &action : actions)
+      hipsGroup->removeAction(action);
 
     QAction *ka = actionCollection()->addAction(i18n("None"), this, SLOT(slotHIPSSource()))
         << i18n("None") << AddToGroup(hipsGroup)
