@@ -60,10 +60,6 @@ FlagComponent::FlagComponent(SkyComposite *parent) : PointListComponent(parent)
     loadFromFile();
 }
 
-FlagComponent::~FlagComponent()
-{
-}
-
 void FlagComponent::draw(SkyPainter *skyp)
 {
     // Return if flags must not be draw
@@ -86,12 +82,10 @@ bool FlagComponent::selected()
 void FlagComponent::loadFromFile()
 {
     bool imageFound = false;
-
     QList<QStringList> flagList = KStarsData::Instance()->userdb()->GetAllFlags();
-    for (int i = 0; i < flagList.size(); ++i)
-    {
-        QStringList flagEntry = flagList.at(i);
 
+    for (auto &flagEntry : flagList)
+    {
         // Read coordinates
         dms r(flagEntry.at(0));
         dms d(flagEntry.at(1));
