@@ -108,12 +108,11 @@ SkyLabeler::SkyLabeler()
 
 SkyLabeler::~SkyLabeler()
 {
-    for (int y = 0; y < screenRows.size(); y++)
+    for (auto &row : screenRows)
     {
-        LabelRow *row = screenRows[y];
-        for (int i = 0; i < row->size(); i++)
+        for (auto &item : *row)
         {
-            delete row->at(i);
+            delete item;
         }
         delete row;
     }
@@ -307,9 +306,10 @@ void SkyLabeler::reset(SkyMap *skyMap)
     for (int y = 0; y <= minMaxY; y++)
     {
         LabelRow *row = screenRows[y];
-        for (int i = 0; i < row->size(); i++)
+
+        for (auto &item : *row)
         {
-            delete row->at(i);
+            delete item;
         }
         row->clear();
     }
@@ -322,9 +322,9 @@ void SkyLabeler::reset(SkyMap *skyMap)
     m_marks = m_hits = m_misses = m_elements = 0;
 
     //----- Clear out labelList -----
-    for (int i = 0; i < labelList.size(); i++)
+    for (auto &item : labelList)
     {
-        labelList[i].clear();
+        item.clear();
     }
 }
 
@@ -621,18 +621,20 @@ void SkyLabeler::drawQueuedLabels()
     // Will just set it to Planet color since this is how it used to be!!
     m_p.setPen(QColor(data->colorScheme()->colorNamed("PNameColor")));
     LabelList list = labelList[RUDE_LABEL];
-    for (int i = 0; i < list.size(); i++)
+
+    for (const auto &item : list)
     {
-        drawRudeNameLabel(list.at(i).obj, list.at(i).o);
+        drawRudeNameLabel(item.obj, item.o);
     }
 }
 
 void SkyLabeler::drawQueuedLabelsType(SkyLabeler::label_t type)
 {
     LabelList list = labelList[type];
-    for (int i = 0; i < list.size(); i++)
+
+    for (const auto &item : list)
     {
-        drawNameLabel(list.at(i).obj, list.at(i).o);
+        drawNameLabel(item.obj, item.o);
     }
 }
 
@@ -686,8 +688,6 @@ void SkyLabeler::printInfo()
     printf("  screenRows=%d elements=%d virtualSize=%.1f Kbytes\n", screenRows.size(), m_elements,
            float(m_size) / 1024.0);
 
-    return;
-
 //    static const char *labelName[NUM_LABEL_TYPES];
 //
 //    labelName[STAR_LABEL]         = "Star";
