@@ -20,8 +20,8 @@
 #endif
 
 #include "skymap.h"
-#include "ksasteroid.h"
 
+#include "ksasteroid.h"
 #include "kstars_debug.h"
 #include "fov.h"
 #include "imageviewer.h"
@@ -38,6 +38,7 @@
 #include "skymapqdraw.h"
 #include "starhopperdialog.h"
 #include "starobject.h"
+#include "syncedcatalogcomponent.h"
 #include "texturemanager.h"
 #include "dialogs/detaildialog.h"
 #include "printing/printingwizard.h"
@@ -124,6 +125,10 @@ SkyMap::SkyMap()
     : QGraphicsView(KStars::Instance()), computeSkymap(true), rulerMode(false), data(KStarsData::Instance()), pmenu(nullptr),
       ClickedObject(nullptr), FocusObject(nullptr), m_proj(nullptr), m_previewLegend(false), m_objPointingMode(false)
 {
+#if !defined(KSTARS_LITE)
+    grabGesture(Qt::PinchGesture);
+    grabGesture(Qt::TapAndHoldGesture);
+#endif
     m_Scale = 1.0;
 
     ZoomRect = QRect();
@@ -788,6 +793,18 @@ void SkyMap::slotRemoveObjectLabel()
     forceUpdate();
 }
 
+void SkyMap::slotRemoveCustomObject()
+{
+    SkyObject* object = clickedObject();
+
+    // The object must be removed from the catalog...
+    data->skyComposite()->internetResolvedComponent()->removeObject(*object);
+    // ...and then in the rest of the places.
+    emit removeSkyObject(object);
+    data->skyComposite()->removeFromNames(object);
+    data->skyComposite()->removeFromLists(object);
+}
+
 void SkyMap::slotAddObjectLabel()
 {
     data->skyComposite()->addNameLabel(clickedObject());
