@@ -25,6 +25,7 @@
 #include "skyobjects/skyline.h"
 
 #include <QGraphicsView>
+#include <QtGlobal>
 #include <QTimer>
 
 class QPainter;
@@ -387,6 +388,9 @@ class SkyMap : public QGraphicsView
          */
     void slotRemoveObjectLabel();
 
+    /** Remove custom object from internet search in the local catalog */
+    void slotRemoveCustomObject();
+
     /** @short Add a Planet Trail to ClickedObject.
          * @note Trails are added simply by calling KSPlanetBase::addToTrail() to add the first point.
          * as long as the trail is not empty, new points will be automatically appended to it.
@@ -502,7 +506,12 @@ class SkyMap : public QGraphicsView
     /** Emitted when a position is clicked */
     void objectClicked(SkyObject *);
 
+    /** Emitted when a sky object is removed from the database */
+    void removeSkyObject(SkyObject *object);
+
   protected:
+    bool event(QEvent *event) override;
+
     /** Process keystrokes:
          * @li arrow keys  Slew the map
          * @li +/- keys  Zoom in and out
@@ -664,6 +673,10 @@ class SkyMap : public QGraphicsView
 
     bool m_objPointingMode { false };
     bool m_fovCaptureMode { false };
+    bool m_touchMode { false };
+    bool m_pinchMode { false };
+    bool m_tapAndHoldMode { false };
+    qreal m_pinchScale { 0.0 };
 
     QWidget *m_SkyMapDraw { nullptr }; // Can be dynamic_cast<> to SkyMapDrawAbstract
 
