@@ -221,12 +221,6 @@ ObservingList::ObservingList()
 #endif
 }
 
-ObservingList::~ObservingList()
-{
-}
-
-// Show Event
-
 void ObservingList::showEvent(QShowEvent *)
 {
     // ONLY run for first ever load
@@ -391,6 +385,7 @@ void ObservingList::slotAddObject(const SkyObject *_obj, bool session, bool upda
         ui->SessionView->resizeColumnsToContents();
         //Note addition in statusbar
         KStars::Instance()->statusBar()->showMessage(i18n("Added %1 to session list.", finalObjectName), 0);
+        SkyMap::Instance()->forceUpdate();
     }
     setSaveImagesButton();
 }
@@ -455,6 +450,7 @@ void ObservingList::slotRemoveObject(const SkyObject *_o, bool session, bool upd
         isModified = true;         //Removing an object should trigger the modified flag
         ui->avt->removeAllPlotObjects();
         ui->SessionView->resizeColumnsToContents();
+        SkyMap::Instance()->forceUpdate();
     }
 }
 
@@ -868,6 +864,7 @@ void ObservingList::slotOpenList()
         TimeHash.clear();
         m_CurrentObject = nullptr;
         m_SessionModel->removeRows(0, m_SessionModel->rowCount());
+        SkyMap::Instance()->forceUpdate();
         //First line is the name of the list. The rest of the file is
         //object names, one per line. With the TimeHash value if present
         QTextStream istream(&f);
@@ -921,6 +918,7 @@ void ObservingList::slotClearList()
             TimeHash.clear();
             isModified = true; //Removing an object should trigger the modified flag
             m_SessionModel->setRowCount(0);
+            SkyMap::Instance()->forceUpdate();
         }
     }
 }
@@ -1210,6 +1208,7 @@ void ObservingList::slotUpdate()
             slotAddObject(obj.data(), true, true);
         }
     }
+    SkyMap::Instance()->forceUpdate();
 }
 
 void ObservingList::slotSetTime()
